# -*- encoding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright: (C) 2012 - Mentis d.o.o., Dravograd
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

{
    "name" : "Slovenian - Accounting",
    "version" : "1.2",
    "author" : "Mentis d.o.o.",
    "website" : "http://www.mentis.si",
    "category" : "Localization/Account Charts",
    "description" : " ",
    "depends" : ["account", "base_iban", "base_vat", "account_chart", "account_cancel"],
    "description" : "Kontni načrt za gospodarske družbe",
    "data" : [
        "data/account.account.type.csv", 
        "data/account.account.template.csv",
        "data/account.tax.code.template.csv",
        "data/account.chart.template.csv",
        "data/account.tax.template.csv",
        "data/account.fiscal.position.template.csv",
        "data/account.fiscal.position.account.template.csv",
        "data/account.fiscal.position.tax.template.csv",
        "l10n_si_wizard.xml"
    ],
    'auto_install': False,
    "installable": True,
}




# -*- encoding: utf-8 -*-
##############################################################################
#    
#    OpenERP, Open Source Management Solution
#    Copyright (C) conexus.at
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.     
#
##############################################################################

import tools
from osv import osv
import addons

class AccountWizard_cd(osv.osv_memory):
	_inherit='wizard.multi.charts.accounts'
		
	_defaults = {
        'code_digits' : 6,
	}

AccountWizard_cd()




#! /usr/bin/env python2
# -*- coding: utf-8 -*-
"""
Replacement (unofficial) `setup.py` for the `l10n_si` module.
Automatically generated by `openerpdist`. See http://noteed.com/openerpdist/.
"""

import setuptools

setuptools.setup(
    name = "openerp-l10n-si",
    version = "7.0.355",
    description = "Slovenian - Accounting",
    long_description = 
"""
Kontni načrt za gospodarske družbe
""",
    url = "http://www.mentis.si",
    author = "Mentis d.o.o.",
    author_email = "TODO",
    classifiers = [
        "Development Status :: 5 - Production/Stable",
        "Environment :: Plugins",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU Affero General Public License v3",
        "Natural Language :: English",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: Implementation :: CPython",
    ],
    license = "AGPL-3",
    package_dir = {
        'openerp.addons.l10n_si': ".",
    },
    packages = ["openerp.addons.l10n_si"],
    package_data = {
        'openerp.addons.l10n_si': ["i18n/*.po*","l10n_si_wizard.xml","data/account.fiscal.position.account.template.csv","data/account.fiscal.position.tax.template.csv","data/account.tax.template.csv","data/account.account.type.csv","data/account.chart.template.csv","data/account.tax.code.template.csv","data/account.account.template.csv","data/account.fiscal.position.template.csv","static/src/img/icon.png","data/account.account.type.csv","data/account.account.template.csv","data/account.tax.code.template.csv","data/account.chart.template.csv","data/account.tax.template.csv","data/account.fiscal.position.template.csv","data/account.fiscal.position.account.template.csv","data/account.fiscal.position.tax.template.csv","l10n_si_wizard.xml"],
    },
    install_requires = ["openerp-account","openerp-base-iban","openerp-base-vat","openerp-account-chart","openerp-account-cancel"],
    tests_require = ["unittest2"],
)
